# -*- coding: utf-8 -*-

"""Top-level package for Zucchini."""

__author__ = """Zucchini Team"""
__email__ = "team@zucc.io"
__version__ = "2.2.1"
